## **Cohesion POC** - Topic Detection Measurement
 


## Cohesion
The Topic-Detection field deals mainly with providing names to given divisions of documents and lacks a quality measurement that provides a rating for the division, that represent a human-subjective score.
<br>
<br>
Cohesion is here to overcome it, includes NLP techniques and considers intra and inter scores in the cohesion formula.
<br>
<br>
The goal of the POC, it to prove that Cohesion has better correlation with NMI heuristic than Coherence which consider as SOA of Topic-Detecion-Measurement domain.
<br>